Autenticação Mecânica / Ficha de Compensação Código de baixa Sacador / Avalista Sacado Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Stoq Retail Management - www.stoq.com.br Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento R$ 10,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 400 N 30/05/2011 8000000400 Cedente Agência/Código cedente Moda Stoq 1565/00000000414-3 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 30/05/2011 104-0 10498.00004 00400.156501 00000.004143 2 49830000001000 104-0 Recibo do Sacado Autenticação Mecânica Cedente Agência/Código Cedente Data Documento Vencimento Sacado Nosso Número N. do documento Valor Documento Demonstrativo Moda Stoq 1565/00000000414-3 30/05/2011 30/05/2011 Client 8000000400 400 10,00 sale XXX XXX - description